@@ -7,6 +7,10 @@
    (at your option) any later version.
 */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <dlfcn.h>
 #include <stdio.h>
 #include <limits.h>
@@ -15,6 +19,9 @@
 /* Simple program to see if dlopen() would succeed. */
 int main(int argc, char **argv)
 {
+#ifdef PAM_STATIC
+  return 77;
+#else
   int i;
   struct stat st;
   char buf[PATH_MAX];
@@ -36,5 +43,6 @@ int main(int argc, char **argv)
     }
   }
   return 0;
+#endif
 }
 
